Stan Math Library: stan/math/prim/scal/fun/identity_constrain.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

identity_constrain.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_IDENTITY_CONSTRAIN_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_IDENTITY_CONSTRAIN_HPP
3
4 namespace stan {
5
6 namespace math {
7
20 template <typename T>
21 inline
22 T identity_constrain(T x) {
23 return x;
24 }
25
39 template <typename T>
40 inline
41 T identity_constrain(const T x, T& /*lp*/) {
42 return x;
43 }
44
45 }
46
47 }
48
49 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::identity_constrain
T identity_constrain(T x)
Returns the result of applying the identity constraint transform to the input.
Definition: identity_constrain.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.